MapboxOptions class

Constructors

MapboxOptions({required WayPoint origin, required WayPoint destination, required bool simulateRoute, required bool setDestinationWithLongTap, String? msg, String? profile, String? style, String? voiceUnits, String? language, bool? alternativeRoute})

Properties

alternativeRoute ↔ bool?
getter/setter pair
destination ↔ WayPoint
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
language ↔ String?
getter/setter pair
msg ↔ String?
getter/setter pair
origin ↔ WayPoint
getter/setter pair
profile ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setDestinationWithLongTap ↔ bool
getter/setter pair
simulateRoute ↔ bool
getter/setter pair
style ↔ String?
getter/setter pair
voiceUnits ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited