WayPoint class

Constructors

WayPoint({required double latitude, required double longitude})
WayPoint.fromJson(String str)
factory
WayPoint.fromMap(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
latitude → double
final
longitude → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited